package de.fitko.fitconnect.api.services.validation;

import de.fitko.fitconnect.api.domain.model.metadata.Metadata;
import de.fitko.fitconnect.api.domain.model.metadata.attachment.Attachment;
import de.fitko.fitconnect.api.domain.model.metadata.data.Data;
import de.fitko.fitconnect.api.domain.model.submission.SubmissionSubmit;
import de.fitko.fitconnect.api.domain.validation.ValidationResult;

/**
 * A validator that ensure the integrity of the transferred {@link Metadata} of a {@link SubmissionSubmit}.
 * Both schema-validation and hash value validation is provided.
 *
 * @see <a href="https://docs.fitko.de/fit-connect/docs/sending/metadata#integrity">Metadata Integrity</a>
 */
public interface MetadataValidator {

    /**
     * Validates the metadata against a given schema.
     *
     * @param metadata the current metadata object that is validated
     * @param jsonSchema the schema the {@link Metadata} is validated against
     *
     * @return a validation result with an optional error list
     */
    ValidationResult validateMetadataSchema(final Metadata metadata, final String jsonSchema);

    /**
     * Checks if the message digest hashes of the metadatas {@link Data} and {@link Attachment}
     * are correct after transmission
     *
     * @param metadata the current {@link Metadata} object that is validated
     *
     * @return a validation result with an optional error list
     */
    ValidationResult validateMetadataHashValues(final Metadata metadata);
}
